﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace ProjectBoat_bae
{
    public class Drawing
    {

        // Класс-сущность
        public ProjectBoat_bae? Boat { get; private set; }

        // Ширина окна
        private int? _pictureWidth = null;

        // Высота окна
        private int? _pictureHeight = null;
        private int _startPosX;
        private int _startPosY;
        private readonly int _BoatWidth = 110;
        private readonly int _BoatHeight = 60;

        public bool Init(int speed, double weight, Color bodyColor, Color
additionalColor, bool body, 
            int width, int height)
        {
            if (width >= _BoatWidth || height >= _BoatHeight)
            {
                _pictureWidth = width;
                _pictureHeight = height;
                Boat = new ProjectBoat_bae();
                Boat.Init(speed,weight, bodyColor, additionalColor,body );
            }
            return true;
        }

        // Установка позиции(запоминаем значение)
        public void SetPosition(int x, int y)
        {
            if (x < 0 || x + _BoatWidth > _pictureWidth)
            {
                x = 0;
            }
            if (y < 0 || y + _BoatHeight > _pictureHeight)
            {
                y = 0;
            }
            _startPosX = x;
            _startPosY = y;
        }

        // Изменение направления перемещения
        public void MoveTransport(DiretionType direction)
        {
            if (Boat == null)
            {
                return;
            }
            switch (direction)
            {
                //влево
                case DiretionType.Left:
                    if (_startPosX - Boat.Step > 0)
                    {
                        _startPosX -= (int)Boat.Step;
                    }
                    break;
                //вверх
                case DiretionType.Up:
                    if (_startPosY - Boat.Step > 0)
                    {
                        _startPosY -= (int)Boat.Step;
                    }
                    break;
                // вправо
                case DiretionType.Right:
                    if (_startPosX + _BoatWidth + Boat.Step < _pictureWidth)
                    {
                        _startPosX += (int)Boat.Step;
                    }
                    break;
                //вниз
                case DiretionType.Down:
                    if (_startPosY + _BoatHeight + Boat.Step < _pictureHeight)
                    {
                        _startPosY += (int)Boat.Step;
                    }
                    break;
            }
        }

        // Прорисовка объекта
        public void DrawTransport(Graphics g)
        {
            if (Boat == null)
            {
                return;
            }
            Pen pen = new(Color.Black);
            Brush additionalBrush = new
            SolidBrush(Boat.AdditionalColor);

            // корпус лодки

            if (Boat.body)
            {
                //корпус
                Brush br = new SolidBrush(Boat.BodyColor);
                g.FillRectangle(br, _startPosX + 20, _startPosY + 5, 70, 50);

                //мотор
                Brush brRed = new SolidBrush(Boat.BodyColor);
                g.FillEllipse(brRed, _startPosX + 7, _startPosY + 12, 35, 35);


                //стекла
                Brush brBlue = new SolidBrush(Color.LightBlue);
                g.FillRectangle(brBlue, _startPosX + 70, _startPosY + 10, 5,
                40);
                g.FillRectangle(brBlue, _startPosX + 35, _startPosY + 8, 35, 2);
                g.FillRectangle(brBlue, _startPosX + 35, _startPosY + 51, 35, 2);

            }
        }
    }
}
